@@ -14,8 +14,10 @@ def test_call():
     class MyCommand(Command):
         pass
 
-    with pytest.raises(TypeError):
-        MyCommand(Namespace())  # Cannot instantiate abstract class
+    command_instance = MyCommand(Namespace())
+
+    with pytest.raises(NotImplementedError):
+        command_instance()  # Call the command instance, it should raise NotImplementedError
 
 
 def test_args():
@@ -32,13 +34,24 @@ def test_help():
     assert MyCommand.help == "Some help"
 
 
+def test_multiple_inheritance():
+    class MyCommand(Command):
+        args = {"--foo": {"help": "Foo help"}}
+
+    class MyOtherCommand(MyCommand):
+        args = {"--bar": {"help": "Bar help"}}
+
+    assert MyOtherCommand.args == {"--foo": {"help": "Foo help"}, "--bar": {"help": "Bar help"}}
+
+
 def test_cli():
     class MyCommand(Command):
         args = {"--foo": {"help": "Foo help"}}
         help = "Some help"
 
-        def __call__(self) -> None:
-            pass
+        def __call__(self) -> int:
+            return 0
 
     args = Namespace(command=MyCommand, foo="bar")
-    assert MyCommand(args).cli_args == args
+    assert MyCommand(args).cliargs == args
+    assert MyCommand(args)() == 0
